@@ -10,9 +10,7 @@ class BitmaskField(fields.Field):
     """
 
     def _serialize(self, value, attr, obj, **kwargs):
-        if value is None:
-            return ""
-        return " ".join(value.flag_list)
+        return NotImplementedError
 
     def _deserialize(self, value, attr, data, **kwargs):
         try:
