@@ -25,13 +25,18 @@ def avlos_endpoints(input):
     return ep_out_list
 
 
+def avlos_enum_eps(input):
+    """
+    Traverse remote dictionary and return a list of enum type endpoints
+    """
+    return [ep for ep in avlos_endpoints(input) if hasattr(ep, "options")]
+
+
 def avlos_bitmask_eps(input):
     """
     Traverse remote dictionary and return a list of bitmask type endpoints
     """
-    ep_list = avlos_endpoints(input)
-    ep_bitmask_list = [ep for ep in ep_list if hasattr(ep, "bitmask")]
-    return ep_bitmask_list
+    return [ep for ep in avlos_endpoints(input) if hasattr(ep, "bitmask")]
 
 
 def as_include(input):
@@ -51,3 +56,11 @@ def file_from_path(input):
     Get the file string from a path string
     """
     return os.path.basename(input)
+
+
+def capitalize_first(input):
+    """
+    Capitalize the first character of a
+    string, leaving the rest unchanged
+    """
+    return input[0].upper() + input[1:]
